import { TransactionReceipt, EventLog } from 'web3-core';
import { Configuration } from '@energyweb/utils-general';
import { PreciseProofEntity } from './PreciseProofEntity';
import { CommitmentStatus, IOwnershipCommitment } from '@energyweb/origin-backend-core';
export interface IShareInCertificate {
    [address: string]: number;
}
export interface IOwners {
    [address: string]: {
        owned: number;
        ownedPrivate: number;
        claimed: number;
    };
}
export interface ICertificate {
    id: number;
    issuer: string;
    deviceId: string;
    energy: number;
    generationStartTime: number;
    generationEndTime: number;
    certificationRequestId: number;
    creationTime: number;
    creationBlockHash: string;
    owners: IOwners;
}
export declare class Entity extends PreciseProofEntity implements ICertificate {
    deviceId: string;
    energy: number;
    generationStartTime: number;
    generationEndTime: number;
    issuer: string;
    creationTime: number;
    creationBlockHash: string;
    ownershipCommitment: IOwnershipCommitment;
    certificationRequestId: number;
    initialized: boolean;
    data: number[];
    private claimedShares;
    private ownedShares;
    private ownedSharesPrivate;
    constructor(id: number, configuration: Configuration.Entity);
    sync(): Promise<Entity>;
    get owners(): IOwners;
    claim(amount?: number): Promise<TransactionReceipt>;
    requestMigrateToPublic(): Promise<TransactionReceipt>;
    migrateToPublic(): Promise<void>;
    transfer(to: string, amount?: number, privately?: boolean): Promise<TransactionReceipt | CommitmentStatus>;
    approvePrivateTransfer(): Promise<TransactionReceipt>;
    revoke(): Promise<TransactionReceipt>;
    getAllCertificateEvents(): Promise<EventLog[]>;
    isOwned(byAddress?: string): boolean;
    ownedVolume(byAddress?: string): {
        publicVolume: number;
        privateVolume: number;
    };
    isClaimed(byAddress?: string): boolean;
    claimedVolume(byAddress?: string): number;
    private calculateOwnership;
    private calculateClaims;
}
export declare const createCertificate: (to: string, value: number, fromTime: number, toTime: number, deviceId: string, configuration: Configuration.Entity<any, any>, isVolumePrivate?: boolean) => Promise<Entity>;
export declare function claimCertificates(certificateIds: number[], configuration: Configuration.Entity): Promise<any>;
export declare function transferCertificates(certificateIds: number[], to: string, configuration: Configuration.Entity): Promise<any>;
export declare function getAllCertificates(configuration: Configuration.Entity): Promise<Entity[]>;
export declare const getAllCertificateEvents: (certId: number, configuration: Configuration.Entity<any, any>) => Promise<EventLog[]>;
